<?php
/**
 * User: nester_a
 * Date: 16.06.14
 */

namespace LMS\Libraries\Routing;

use LMS\Libraries\Exception;
use LMS\Libraries\ServiceLocator;

jimport('joomla.application.component.controller');

class Handler
{

	/**
	 * @var array
	 */
	private $parsedParts = array();

	/**
	 * @var \JSession
	 */
	private $session;

	public function __construct()
	{
		ServiceLocator::load('lib.routing');
		$this->session = ServiceLocator::get('routing_session');
	}

	/**
	 *
	 */
	public function handle()
	{
		$this->_parse();
		$this->savePreviousURL();

		if(!file_exists(JPATH_COMPONENT . '/tools/'.$this->parsedParts[0])){
			throw new Exception\UndefinedTool('There is no tool "' . $this->parsedParts[0].'"');
		}

		ServiceLocator::load('lib.base');
		ServiceLocator::load('tool.'.strtolower($this->parsedParts[0]));

		try{			
			$controller = $this->loadController(array(
				'namespace' => 'LMS\\Tools\\'.ucfirst($this->parsedParts[0]),
				'base_path' => JPATH_COMPONENT . '/tools/'.$this->parsedParts[0]
			));
		}
		catch(\LMS\Libraries\Exception\Access\Forbidden $e){
			throw $e;
		}
		catch(\Exception $e){			
			throw new Exception\UndefinedTool($e->getMessage());
		}


		$controller->execute(\JFactory::getApplication()->input->get('task'));
		$controller->redirect();
	}

	/**
	 * @return string
	 */
	public function getToolName()
	{
		$this->_parse();
		return $this->parsedParts[0];
	}

	/**
	 *
	 */
	public function redirectBack()
	{
		JLMSRedirect($this->getPreviousURL());
	}

	/**
	 * @param $url
	 */
	public function setBackUrl($url)
	{
		$this->session->set('routing_back_url',$url);
	}

	/**
	 *
	 */
	private function _parse()
	{
		if(!empty($this->parsedParts)){
			return;
		}

		$task = \JFactory::getApplication()->input->get('task');
		$this->parsedParts = explode('.', $task);

		\JFactory::getApplication()->input->set('tool', $this->parsedParts[0]);
		\JFactory::getApplication()->input->set('task', (isset($this->parsedParts[1]) ? $this->parsedParts[1] : $this->parsedParts[0]) .'.'. (isset($this->parsedParts[2]) ? $this->parsedParts[2] : 'display' ));

	}

	/**
	 *
	 */
	private function savePreviousURL()
	{
		$this->session->set('routing_back_url', isset($_SERVER['HTTP_REFERER']) ? $_SERVER['HTTP_REFERER'] : sefRelToAbs('index.php?option=com_joomla_lms'.$this->getCourseUrlPart()));
	}

	/**
	 * @return mixed
	 */
	private function getPreviousURL()
	{
		return $this->session->get('routing_back_url', sefRelToAbs('index.php?option=com_joomla_lms'.$this->getCourseUrlPart()));
	}

	/**
	 * @return string
	 */
	private function getCourseUrlPart()
	{
		$courseID = \JFactory::getApplication()->input->get('course_id', \JFactory::getApplication()->input->get('id', false));
		$courseLink = '';
		if($courseID){
			$courseLink = "&task=details_course&id=".$courseID;
		}
		return $courseLink;
	}


	/**
	 * @param array $config
	 * @return \LMS\Libraries\Base\Controller
	 * @throws \InvalidArgumentException
	 */
	private function loadController($config = array())
	{
		$input = \JFactory::getApplication()->input;

		// Get the environment configuration.
		$basePath = array_key_exists('base_path', $config) ? $config['base_path'] : JPATH_COMPONENT;
		$format   = $input->getWord('format');
		$command  = $input->get('task', 'display');

		// Check for array format.
		$filter = \JFilterInput::getInstance();

		if (is_array($command)){
			$command = $filter->clean(array_pop(array_keys($command)), 'cmd');
		}
		else{
			$command = $filter->clean($command, 'cmd');
		}

		// Check for a controller.task command.
		if (strpos($command, '.') !== false)
		{
			// Explode the controller.task command.
			list ($type, $task) = explode('.', $command);

			// Define the controller filename and path.
			$file = self::createFileName('controller', array('name' => $type, 'format' => $format));
			$path = $basePath . '/controllers/' . $file;

			// Reset the task without the controller context.
			$input->set('task', $task);
		}
		else
		{
			// Base controller.
			$type = null;
			$task = $command;

			// Define the controller filename and path.
			$file       = self::createFileName('controller', array('name' => 'controller', 'format' => $format));
			$path       = $basePath . '/' . $file;
			$backupfile = self::createFileName('controller', array('name' => 'controller'));
			$backuppath = $basePath . '/' . $backupfile;
		}

		// Get the controller class name.
		$class = $config['namespace'] . '\\Controllers\\' . ucfirst($type);

		// Include the class if not present.
		if (!class_exists($class))
		{
			// If the controller file path exists, include it.
			if (file_exists($path))
			{				
				require_once $path;
			}
			elseif (isset($backuppath) && file_exists($backuppath))
			{
				require_once $backuppath;
			}
			else
			{
				throw new \InvalidArgumentException(\JText::sprintf('JLIB_APPLICATION_ERROR_INVALID_CONTROLLER', $type, $format));
			}
		}
	
		// Instantiate the class.
		if (class_exists($class))
		{			
			return new $class($config);
		}
		else
		{			
			throw new \InvalidArgumentException(\JText::sprintf('JLIB_APPLICATION_ERROR_INVALID_CONTROLLER_CLASS', $class));
		}
	}

	/**
	 * Create the filename for a resource.
	 *
	 * @param   string  $type   The resource type to create the filename for.
	 * @param   array   $parts  An associative array of filename information. Optional.
	 *
	 * @return  string  The filename.
	 *
	 * @note    Replaced _createFileName.
	 * @since   12.2
	 */
	protected static function createFileName($type, $parts = array())
	{
		$filename = '';

		switch ($type)
		{
			case 'controller':
				if (!empty($parts['format']))
				{
					if ($parts['format'] == 'html')
					{
						$parts['format'] = '';
					}
					else
					{
						$parts['format'] = '.' . $parts['format'];
					}
				}
				else
				{
					$parts['format'] = '';
				}

				$filename = strtolower($parts['name'] . $parts['format'] . '.php');
				break;

			case 'view':
				if (!empty($parts['type']))
				{
					$parts['type'] = '.' . $parts['type'];
				}
				else
				{
					$parts['type'] = '';
				}

				$filename = strtolower($parts['name'] . '/view' . $parts['type'] . '.php');
				break;
		}

		return $filename;
	}
}