<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_joomla_lms
 *
 */

namespace LMS\Tools\Conference\Controllers;

defined('_JEXEC') or die;

require __DIR__ .'/conference.php';

/**
 * @package     Joomla.Site
 * @subpackage  com_joomla_lms
 * @since       3.1
 */
class Archive extends Conference
{

	public function __construct($config=array())
	{
		parent::__construct($config);
		$this->input->set('view', 'archive');
	}


	/**
	 * Method to display a view.
	 *
	 * @param   boolean			If true, the view output will be cached
	 * @param   array  An array of safe url parameters and their variable types, for valid values see {@link JFilterInput::clean()}.
	 *
	 * @return  \JController		This object to support chaining.
	 * @since   1.5
	 */
	public function display($cachable = false, $urlparams = false)
	{
		$this->getModel('Test');

		$limit = $this->input->get('limit', $this->session->get('list_limit', $this->config->get('list_limit')));
		$this->session->set('list_limit', $limit);
		$limitStart = $this->input->get('limitstart', 0);

		$params = $this->container['registry']->get('params');
		$params['limit'] = $limit;
		$params['limitStart'] = $limitStart;
		$this->container['registry']->set('params', $params);

		$results = $this->dispatcher->trigger( 'onConferenceShowArchive', array($this->container));
		$result = $this->responseHandler->handle($results);
		$this->_render(array('content' => $result));
	}

	/**
	 * Method to start recording
	 */
	public function start()
	{
		$results = $this->dispatcher->trigger( 'onConferenceStartRecord', array($this->container));
		$this->responseHandler->handle($results);
	}

	/**
	 * Method to save changes to record
	 */
	public function save()
	{
		if(!$this->acl->CheckPermissions('conference', 'manage')){
			throw new \LMS\Libraries\Exception\Access\Forbidden(_JLMS_ERROR_ACCESS_FORBIDDEN);
		}
		$params = $this->container['registry']->get('params');
		$results = $this->dispatcher->trigger( 'onConferenceSaveRecord', array($this->container));
		$this->responseHandler->handle($results);

		$this->setRedirect(html_entity_decode(sefRelToAbs('index.php?option=com_joomla_lms&Itemdid='.$params['Itemid'].'&task=conference.booking&id='.$params['courseID'])));
	}

	/**
	 * Method to show form to edit existing record
	 */
	public function edit()
	{
		if(!$this->acl->CheckPermissions('conference', 'manage')){
			throw new \LMS\Libraries\Exception\Access\Forbidden(_JLMS_ERROR_ACCESS_FORBIDDEN);
		}

		$results = $this->dispatcher->trigger( 'onConferenceEditRecord', array($this->container));
		$result = $this->responseHandler->handle($results);
		$this->_render(array('content' => $result));
	}

	/**
	 * Method to delete existing record
	 */
	public function delete()
	{
		if(!$this->acl->CheckPermissions('conference', 'manage')){
			throw new \LMS\Libraries\Exception\Access\Forbidden(_JLMS_ERROR_ACCESS_FORBIDDEN);
		}

		$params = $this->container['registry']->get('params');
		$results = $this->dispatcher->trigger( 'onConferenceDeleteRecord', array($this->container));
		$this->responseHandler->handle($results);
		$this->setRedirect(html_entity_decode(sefRelToAbs('index.php?option=com_joomla_lms&Itemdid='.$params['Itemid'].'&task=conference.archive&id='.$params['courseID'])));
	}

	/**
	 * Method to publish/unpublish existing record
	 */
	public function change()
	{
		if(!$this->acl->CheckPermissions('conference', 'manage')){
			throw new \LMS\Libraries\Exception\Access\Forbidden(_JLMS_ERROR_ACCESS_FORBIDDEN);
		}

		$params = $this->container['registry']->get('params');

		$recordIDs = $this->input->get('recordID', 0);
		if(empty($recordIDs)){
			$this->msgManager->error('Record to process has not been set');
			$this->setRedirect(html_entity_decode(sefRelToAbs('index.php?option=com_joomla_lms&Itemdid='.$params['Itemid'].'&task=conference.archive&id='.$params['courseID'])));
			$this->redirect();
		}

		$results = $this->dispatcher->trigger( 'onConferenceChangeRecord', array($this->container));
		$this->responseHandler->handle($results);
		$this->setRedirect(html_entity_decode(sefRelToAbs('index.php?option=com_joomla_lms&Itemdid='.$params['Itemid'].'&task=conference.archive&id='.$params['courseID'])));
	}

	public function playback()
	{
		$results = $this->dispatcher->trigger( 'onConferencePlayback', array($this->container));
		$result = $this->responseHandler->handle($results);
		$this->_render(array('content' => $result));
	}

}