<?php

defined('JPATH_PLATFORM') or die;

use LMS\Libraries;
use LMS\Tools\Courses\Helpers;

JFormHelper::loadFieldClass('media');

class JFormFieldJBMedia extends JFormFieldMedia
{	
	public $type = 'JBMedia';

	protected function getInput()
	{	
		return $this->ckeditorMedia();
	}

	protected function ckeditorMedia()
	{	
		$doc	= Libraries\ServiceLocator::get('doc');		
		$config = Libraries\ServiceLocator::get('config');
		$user = Libraries\ServiceLocator::get('user');
		
		$courseId = $config->get('course_id');
		
		$link = (string) $this->element['link'];
		$folder = $this->element['folder'] ? $this->element['folder']  : 'default';
		
		if (!self::$initialised)
		{

			// Load the modal behavior script.
			JHtml::_('behavior.modal');

			// Build the script.
			$script = array();
			$script[] = '	function jInsertFieldValue(value, id) {';
			$script[] = '		var old_value = document.id(id).value;';
			$script[] = '		if (old_value != value) {';
			$script[] = '			var elem = document.id(id);';
			$script[] = '			elem.value = value;';
			$script[] = '			elem.fireEvent("change");';
			$script[] = '			if (typeof(elem.onchange) === "function") {';
			$script[] = '				elem.onchange();';
			$script[] = '			}';
			$script[] = '			jMediaRefreshPreview(id);';
			$script[] = '		}';
			$script[] = '	}';

			$script[] = '	function jMediaRefreshPreview(id) {';
			$script[] = '		var value = document.id(id).value;';
			$script[] = '		var img = document.id(id + "_preview");';
			$script[] = '		if (img) {';
			$script[] = '			if (value) {';
			$script[] = '				img.src = value;';
			$script[] = '				document.id(id + "_preview_empty").setStyle("display", "none");';
			$script[] = '				document.id(id + "_preview_img").setStyle("display", "");';
			$script[] = '			} else { ';
			$script[] = '				img.src = ""';
			$script[] = '				document.id(id + "_preview_empty").setStyle("display", "");';
			$script[] = '				document.id(id + "_preview_img").setStyle("display", "none");';
			$script[] = '			} ';
			$script[] = '		} ';
			$script[] = '	}';

			$script[] = '	function jMediaRefreshPreviewTip(tip)';
			$script[] = '	{';
			$script[] = '		tip.setStyle("display", "block");';
			$script[] = '		var img = tip.getElement("img.media-preview");';
			$script[] = '		var id = img.getProperty("id");';
			$script[] = '		id = id.substring(0, id.length - "_preview".length);';
			$script[] = '		jMediaRefreshPreview(id);';
			$script[] = '	}';

			// Add the script to the document head.
			$doc->addScriptDeclaration(implode("\n", $script));

			self::$initialised = true;
		}

		// Initialize variables.
		$html = array();

		// The Preview.
		$preview = (string) $this->element['preview'];
		$showPreview = true;
		$showAsTooltip = false;
		switch ($preview)
		{
			case 'false':
			case 'none':
				$showPreview = false;
				break;
			case 'true':
			case 'show':
				break;
			case 'tooltip':
			default:
				$showAsTooltip = true;
				$options = array(
					'onShow' => 'jMediaRefreshPreviewTip',
				);
				JHtml::_('behavior.tooltip', '.hasTipPreview', $options);
				break;
		}

		$attr = '';

		// Initialize some field attributes.
		$attr .= $this->element['class'] ? ' class="' . (string) $this->element['class'] . '"' : '';
		$attr .= $this->element['size'] ? ' size="' . (int) $this->element['size'] . '"' : '';		

		// Initialize JavaScript field attributes.
		$attr .= $this->element['onchange'] ? ' onchange="' . (string) $this->element['onchange'] . '"' : '';
		$html[] = '<div class="btn-wrapper input-prepend">';
		if ($showPreview)
		{			
			if ($this->value && file_exists(JPATH_ROOT . '/' . $this->value))
			{
				$src = JURI::root() . $this->value;
			}
			else
			{
				$src = '';
			}

			$imgAttr = array(
				'id' => $this->id . '_preview',
				'class' => 'btn btn-default media-preview',
				'style' => 'max-width:160px; max-height:100px;'
			);
			$img = JHtml::image($src, '', $imgAttr);

			$previewImg = '<div id="' . $this->id . '_preview_img"' . ($src ? '' : ' style="display:none"') . '>' . $img . '</div>';
			$previewImgEmpty = '<div id="' . $this->id . '_preview_empty"' . ($src ? ' style="display:none"' : '') . '></div>';

			$margin = "";
			$text = "";
			if (JFactory::getApplication()->isAdmin())
			{
				$margin = "-10px";
				$text = JText::_('JLIB_FORM_MEDIA_PREVIEW_TIP_TITLE');
			}
			else
			{
				$margin = "-5px";
			}
			
			if ($showAsTooltip)
			{
				$tooltip = $previewImgEmpty.$previewImg;
				
				$tip = '<strong>'.JText::_('JLIB_FORM_MEDIA_PREVIEW_SELECTED_IMAGE').'</strong>';
				$tip .= $tooltip;				
				$tip = htmlspecialchars($tip, ENT_COMPAT, 'UTF-8');
											
				$html[] = '<a class="btn btn-default jb-preview hasTipPreview" title="'.$tip.'"><span class="icon-eye-open"></span></a>';
				JHtml::_('behavior.tooltip', '.hasTipPreview');				
			}
			else
			{
				$html[] = ' ' . $previewImgEmpty;
				$html[] = ' ' . $previewImg;
			}		
		}
		
		if ($this->value && !strpos($this->value, '/'))
		{
			$value = Helpers\Images::fileUrlRel($this->value, $folder, $user->id);
		} else {
			$value = $this->value;
		}

		// The text field.				
		$html[] = '	<input type="text" name="' . $this->name . '" id="' . $this->id . '"' . ' value="'
			. htmlspecialchars($value, ENT_COMPAT, 'UTF-8') . '"' . ' readonly="readonly"' . $attr . ' />';	
		
		$listUrl = array();
		$listUrl[] = 'option=com_joomla_lms';		
		$listUrl[] = 'task=courses.images.show';
		$listUrl[] = 'course_id='.$courseId;
		$listUrl[] = 'tmpl=component';
		$listUrl[] = 'folder='.$folder;
		$listUrl[] = 'folderid='.$user->id;
		
		$imageBrowserListUrl = urlencode(JURI::root().'index.php?'.implode('&', $listUrl));		
				
		$uploadUrl = array();
		$uploadUrl[] = 'option=com_joomla_lms';		
		$uploadUrl[] = 'task=courses.images.upload';
		$uploadUrl[] = 'course_id='.$courseId;
		$uploadUrl[] = 'tmpl=component';
		$uploadUrl[] = 'folder='.$folder;
		$uploadUrl[] = 'folderid='.$user->id;	
		
		$imageBrowserUploadUrl = urlencode(JURI::root().'index.php?'.implode('&', $uploadUrl));

		$link = JURI::root().'components/com_joomla_lms/tools/courses/assets/ckeditor/plugins/imagebrowser/browser/browser.html?listUrl='.urlencode($imageBrowserListUrl).'&uploadUrl='.urlencode($imageBrowserUploadUrl).'&CKEditor=&CKEditorFuncNum=0&langCode=en&fieldid='.$this->id;

		// The button.
		$html[] = '	<div class="btn-group">';		
		$html[] = '		<a class="btn btn-default" title="' . JText::_('JLIB_FORM_BUTTON_SELECT') . '"' . ' href="'
			. ($this->element['readonly'] ? '#'
				: 'javascript: Joomla.popupWindow( \''. $link .'\', \'ckmedia_'.$this->id.'\', \'800\', \'600\', \'no\')'
					.'">'
				);
		$html[] = JText::_('JLIB_FORM_BUTTON_SELECT') . '</a>';		

		$html[] = '		<a class="btn btn-default jb_clearBtn" title="' . JText::_('JLIB_FORM_BUTTON_CLEAR') . '"' . ' href="#" onclick="';
		$html[] = 'jInsertFieldValue(\'\', \'' . $this->id . '\');';
		$html[] = 'return false;';
		$html[] = '">'.JText::_('JLIB_FORM_BUTTON_CLEAR');
		$html[] = '</a>';		
		$html[] = '	</div>';		
		$html[] = '</div>'; //btn-wrapper close tag

		return implode('', $html);
	}
}
