<?php

namespace LMS\Tools\Users\View;

defined('_JEXEC') or die;

use LMS\Libraries\Base;

class Users extends Base\View
{
	public function __construct($config=array())
	{
		$this->viewDir = __DIR__;
		parent::__construct($config);
	}

	public function userList()
	{		
		$model = $this->getModel();		
				
		$this->items = $model->getItems();		
		$this->display();		
	}
	
	public function studentsListModal()
	{	
		$model = $this->getModel();
		
		$this->filter			= $model->getForm('filters', array('control'=>'filter'));
		$this->form				= $model->getForm('modal');
		
		$template = $this->template;
		
		$this->addStyleSheet('/templates/'.$template.'/css/template.css');
		$this->addStyleSheet('/tools/users/assets/css/style.css');		
		$this->addScript('/assets/js/storage.js');
		$this->addScript('/tools/users/assets/js/script.js');
		
		$this->contentHeader = $this->widget('contentheader', array('title' => _JLMS_RECIPIENTS, 'icon' => 'users_management'));
		
		$this->contentToolbar = $this->widget('contenttoolbar');				
		$this->contentToolbar->addCustomButton(array('title' => \JText::_('_JLMS_OK'), 'type' => 'button', 'id' => 'contenttoolbar-button-save', 'class' => 'btn-primary'));

		$this->tableGroups	 = $this->groupsTable();
		$this->tableStudents = $this->studentsTable();
		$this->tableStaff	 = $this->staffTable();
		
		$this->setLayout('modal');		
		$this->display();		
	}
	
	public function studentsTable($ajax = false) {
		$model = $this->getModel('students');
		
		$pagination = $model->getPagination();		
		$pagination->setAdditionalUrlParam('context', 'students');		

		$params = array(
			'cols'=>array(
				'username'=> \JText::_('_JLMS_USERNAME'), 
				'name'=> \JText::_('_JLMS_NAME'), 
				'email' => \JText::_('_JLMS_EMAIL'), 
				'group'=> \JText::_('_JLMS_USERGROUP')		
			),
			'items'=> $model->getItems(),
			'ajax'=> $ajax,
			'data'=> array('id', 'group_id'),			
			'pagination'=> $pagination,
			'type'=> 'students',
		);
		
		if(!$ajax) {				
			$filters = $model->getState('list.filters');			
			$filterSearch = isset($filters['search'])?$filters['search']:'';		
			
			$filtersForm = $model->getForm('modalfilters', array('control'=>'filter'));				
			$filtersForm->bind(array('search' => array('search'=>$filterSearch, 'total'=>$pagination->get('total'))));
					
			$filters = array();
			$filters[] = $filtersForm->getField('search');
			$filters[] = $filtersForm->getField('usergroup');
		
			$params['filters'] = $filters;
		}
			
		return $this->widget('table', $params, 'students');
	}

	public function groupsTable($ajax = false) {
		$modelGroups = $this->getModel('groups');			
		
		$pagination = $modelGroups->getPagination();		
		$pagination->setAdditionalUrlParam('context', 'groups');
				
		$params = array(
			'cols'=>array(				
				'name'=> \JText::_('_JLMS_NAME')				
			),
			'items'=> $modelGroups->getItems(),
			'ajax'=> $ajax,
			'data'=> array('id'),
			'context'=> $this->get('context'),			
			'pagination'=> $pagination,
			'type'=> 'groups',
		);
		
		if(!$ajax) {			
			$filters = $modelGroups->getState('list.filters');			
			$filterSearch = isset($filters['search'])?$filters['search']:'';		
			
			$filtersForm = $modelGroups->getForm('modalfilters', array('control'=>'filter'));				
			$filtersForm->bind(array('groups_search' => array('search'=>$filterSearch, 'total'=>$pagination->get('total'))));
			
			$filters = array();
			$filters[] = $filtersForm->getField('groups_search');
			
			$params['filters'] = $filters;
		}
		
		return $this->widget('table', $params, 'groups');
	}
	
	public function staffTable($ajax = false) {
		$modelStaff = $this->getModel('staff');			
		
		$pagination = $modelStaff->getPagination();		
		$pagination->setAdditionalUrlParam('context', 'staff');		
		
		$params = array(
			'cols'=>array(				
				'name'=> \JText::_('_JLMS_NAME'), 
				'email' => \JText::_('_JLMS_EMAIL')				
			),
			'items'=> $modelStaff->getItems(),
			'ajax'=> $ajax,
			'data'=> array('id'),			
			'pagination'=> $pagination,
			'type'=> 'staff',
		);		
		
		if(!$ajax) {			
			$filters = $modelStaff->getState('list.filters');			
			$filterSearch = isset($filters['search'])?$filters['search']:'';		
			
			$filtersForm = $modelStaff->getForm('modalfilters', array('control'=>'filter'));				
			$filtersForm->bind(array('staff_search' => array('search'=>$filterSearch, 'total'=>$pagination->get('total'))));
			
			$filters = array();
			$filters[] = $filtersForm->getField('staff_search');
		
			$params['filters'] = $filters;
		}
		
		return $this->widget('table', $params, 'staff');
	}
}